[Libreoffice-commits] .: 2 commits - scp2/source setup_native/source shell/inc shell/source

Andras Timar timar at kemper.freedesktop.org
Tue Mar 27 06:40:23 PDT 2012


 scp2/source/winexplorerext/file_winexplorerext.scp                          |    3 +
 setup_native/source/win32/customactions/reg4allmsdoc/reg4allmsi.cxx         |    4 -
 setup_native/source/win32/customactions/reg4msdoc/registrar.cxx             |    4 -
 setup_native/source/win32/customactions/shellextensions/shellextensions.cxx |   16 +++---
 shell/inc/internal/config.hxx                                               |    8 +--
 shell/source/win32/shlxthandler/ooofilt/ooofilt.cxx                         |   26 +++++-----
 shell/source/win32/shlxthandler/ooofilt/ooofilt.hxx                         |   12 ++--
 shell/source/win32/shlxthandler/prophdl/propertyhdl.cxx                     |   10 +--
 8 files changed, 43 insertions(+), 40 deletions(-)

New commits:
commit 99d1eff4a843811bf5cb192aa3a2dc29f85d935a
Author: Andras Timar <atimar at suse.com>
Date:   Tue Mar 27 15:36:11 2012 +0200

    replace OpenOffice.org to LibreOffice in registry keys

diff --git a/setup_native/source/win32/customactions/reg4allmsdoc/reg4allmsi.cxx b/setup_native/source/win32/customactions/reg4allmsdoc/reg4allmsi.cxx
index 7b9cfc9..4fd1700 100644
--- a/setup_native/source/win32/customactions/reg4allmsdoc/reg4allmsi.cxx
+++ b/setup_native/source/win32/customactions/reg4allmsdoc/reg4allmsi.cxx
@@ -117,7 +117,7 @@ static BOOL CheckExtensionInRegistry( LPCSTR lpSubKey )
             {   // We will replace registration for word pad
                 bRet = true;
             }
-            else if ( strncmp( szBuffer, "OpenOffice.org.", 15 ) == 0 )
+            else if ( strncmp( szBuffer, "LibreOffice.", 15 ) == 0 )
             {   // We will replace registration for our own types, too
                 bRet = true;
             }
@@ -330,7 +330,7 @@ static void saveOldRegistration( LPCSTR lpSubKey )
             szBuffer[nSize] = '\0';
 
             // No need to save assocations for our own types
-            if ( strncmp( szBuffer, "OpenOffice.org.", 15 ) != 0 )
+            if ( strncmp( szBuffer, "LibreOffice.", 15 ) != 0 )
             {
                 // Save the old association
                 RegSetValueExA( hKey, "OOoBackupAssociation", 0,
diff --git a/setup_native/source/win32/customactions/reg4msdoc/registrar.cxx b/setup_native/source/win32/customactions/reg4msdoc/registrar.cxx
index 5220b1e..967f9c8 100644
--- a/setup_native/source/win32/customactions/reg4msdoc/registrar.cxx
+++ b/setup_native/source/win32/customactions/reg4msdoc/registrar.cxx
@@ -55,10 +55,10 @@ namespace /* private */
 
 Registrar::Registrar(const RegistrationContextInformation& RegContext) :
     m_ContextInformation(RegContext),
-    FORWARD_KEY_PREFIX(L"OpenOffice.org"),//FORWARD_KEY_PREFIX(L"soffice6"),
+    FORWARD_KEY_PREFIX(L"LibreOffice"),
     DEFAULT_VALUE_NAME(L""),
     BACKUP_VALUE_NAME(L"Backup"),
-    PRIVATE_BACKUP_KEY_NAME(L"OpenOffice.org.reg4msdocmsi"),//PRIVATE_BACKUP_KEY_NAME(L"soffice6.bak"),
+    PRIVATE_BACKUP_KEY_NAME(L"LibreOffice.reg4msdocmsi"),
     REGISTRATION_STATE(L"Reg4MsDocState")
 {
     m_RootKey = WindowsRegistry().GetClassesRootKey();
diff --git a/setup_native/source/win32/customactions/shellextensions/shellextensions.cxx b/setup_native/source/win32/customactions/shellextensions/shellextensions.cxx
index 01f0b30..790a342 100644
--- a/setup_native/source/win32/customactions/shellextensions/shellextensions.cxx
+++ b/setup_native/source/win32/customactions/shellextensions/shellextensions.cxx
@@ -59,10 +59,10 @@
     </MSDN>
 
     We add the following entries to the respective registry key
-    "{C52AF81D-F7A0-4AAB-8E87-F80A60CCD396}"="OpenOffice.org Column Handler"
-    "{087B3AE3-E237-4467-B8DB-5A38AB959AC9}"="OpenOffice.org Infotip Handler"
-    "{63542C48-9552-494A-84F7-73AA6A7C99C1}"="OpenOffice.org Property Sheet Handler"
-    "{3B092F0C-7696-40E3-A80F-68D74DA84210}"="OpenOffice.org Thumbnail Viewer"
+    "{C52AF81D-F7A0-4AAB-8E87-F80A60CCD396}"="LibreOffice Column Handler"
+    "{087B3AE3-E237-4467-B8DB-5A38AB959AC9}"="LibreOffice Infotip Handler"
+    "{63542C48-9552-494A-84F7-73AA6A7C99C1}"="LibreOffice Property Sheet Handler"
+    "{3B092F0C-7696-40E3-A80F-68D74DA84210}"="LibreOffice Thumbnail Viewer"
 
     These shell extensions are implemented in the 'shell' project. We ignore registration
     failures because of insufficient privileges. The reason is: On systems which restrict the
@@ -95,10 +95,10 @@ struct RegistryEntry
     TCHAR* Value;
 };
 
-RegistryEntry ColumnHandler = { TEXT("{C52AF81D-F7A0-4AAB-8E87-F80A60CCD396}"), TEXT("OpenOffice.org Column Handler") };
-RegistryEntry InfotipHandler = { TEXT("{087B3AE3-E237-4467-B8DB-5A38AB959AC9}"), TEXT("OpenOffice.org Infotip Handler") };
-RegistryEntry PropHandler = { TEXT("{63542C48-9552-494A-84F7-73AA6A7C99C1}"), TEXT("OpenOffice.org Property Sheet Handler") };
-RegistryEntry ThumbViewer = { TEXT("{3B092F0C-7696-40E3-A80F-68D74DA84210}"), TEXT("OpenOffice.org Thumbnail Viewer") };
+RegistryEntry ColumnHandler = { TEXT("{C52AF81D-F7A0-4AAB-8E87-F80A60CCD396}"), TEXT("LibreOffice Column Handler") };
+RegistryEntry InfotipHandler = { TEXT("{087B3AE3-E237-4467-B8DB-5A38AB959AC9}"), TEXT("LibreOffice Infotip Handler") };
+RegistryEntry PropHandler = { TEXT("{63542C48-9552-494A-84F7-73AA6A7C99C1}"), TEXT("LibreOffice Property Sheet Handler") };
+RegistryEntry ThumbViewer = { TEXT("{3B092F0C-7696-40E3-A80F-68D74DA84210}"), TEXT("LibreOffice Thumbnail Viewer") };
 
 BOOL GetMsiProp( MSIHANDLE hMSI, const char* pPropName, char** ppValue )
 {
diff --git a/shell/inc/internal/config.hxx b/shell/inc/internal/config.hxx
index 37de9ca..0d3cbf5 100644
--- a/shell/inc/internal/config.hxx
+++ b/shell/inc/internal/config.hxx
@@ -43,10 +43,10 @@
 #define MODULE_NAME_FILTER TEXT("ooofilt.dll")
 #endif
 
-#define COLUMN_HANDLER_DESCRIPTIVE_NAME    TEXT("OpenOffice.org Column Handler")
-#define INFOTIP_HANDLER_DESCRIPTIVE_NAME   TEXT("OpenOffice.org Infotip Handler")
-#define PROPSHEET_HANDLER_DESCRIPTIVE_NAME TEXT("OpenOffice.org Property Sheet Handler")
-#define THUMBVIEWER_HANDLER_DESCRIPTIVAE_NAME TEXT("OpenOffice.org Thumbnail Viewer")
+#define COLUMN_HANDLER_DESCRIPTIVE_NAME    TEXT("LibreOffice Column Handler")
+#define INFOTIP_HANDLER_DESCRIPTIVE_NAME   TEXT("LibreOffice Infotip Handler")
+#define PROPSHEET_HANDLER_DESCRIPTIVE_NAME TEXT("LibreOffice Property Sheet Handler")
+#define THUMBVIEWER_HANDLER_DESCRIPTIVAE_NAME TEXT("LibreOffice Thumbnail Viewer")
 
 #define META_CONTENT_NAME               "meta.xml"
 #define DOC_CONTENT_NAME                "content.xml"
diff --git a/shell/source/win32/shlxthandler/ooofilt/ooofilt.hxx b/shell/source/win32/shlxthandler/ooofilt/ooofilt.hxx
index 5ecd917..927f6cc 100644
--- a/shell/source/win32/shlxthandler/ooofilt/ooofilt.hxx
+++ b/shell/source/win32/shlxthandler/ooofilt/ooofilt.hxx
@@ -29,7 +29,7 @@
 #include "internal/types.hxx"
 
 //+-------------------------------------------------------------------------
-//  Contents:   OpenOffice.org filter declarations
+//  Contents:   LibreOffice filter declarations
 //  Platform:   Windows 2000, Windows XP
 //--------------------------------------------------------------------------
 
@@ -51,7 +51,7 @@ GUID const guidStorage = PSGUID_STORAGE;      // GUID for storage property set
 
 //C-------------------------------------------------------------------------
 //  Class:      COooFilter
-//  Purpose:    Implements interfaces of OpenOffice.org filter
+//  Purpose:    Implements interfaces of LibreOffice filter
 //--------------------------------------------------------------------------
 
 // OooFilter Class ID
@@ -64,17 +64,17 @@ GUID const CLSID_COooFilter =
     { 0xa2, 0x9d, 0x5d, 0x46, 0xd8, 0xb3, 0x92, 0x62 }
 };
 
-// OpenOffice.org Persistent Handler Class ID
+// LibreOffice Persistent Handler Class ID
 // {7BC0E713-5703-45be-A29D-5D46D8B39262}
 const CLSID CLSID_PERSISTENT_HANDLER =
 {0x7bc0e713, 0x5703, 0x45be, {0xa2, 0x9d, 0x5d, 0x46, 0xd8, 0xb3, 0x92, 0x62}};
 
-// OpenOffice.org Persistent Handler Addin Registered Class ID
+// LibreOffice Persistent Handler Addin Registered Class ID
 // {89BCB740-6119-101A-BCB7-00DD010655AF}
 const CLSID CLSID_PERSISTENT_HANDLER_ADDIN =
 {0x89bcb740, 0x6119, 0x101a, {0xbc, 0xb7, 0x00, 0xdd, 0x01, 0x06, 0x55, 0xaf}};
 
-// OpenOffice.org Filter Handler Class ID
+// LibreOffice Filter Handler Class ID
 // {7BC0E710-5703-45be-A29D-5D46D8B39262}
 const CLSID CLSID_FILTER_HANDLER =
 {0x7bc0e710, 0x5703, 0x45be, {0xa2, 0x9d, 0x5d, 0x46, 0xd8, 0xb3, 0x92, 0x62}};
@@ -171,7 +171,7 @@ private:
 
 //C-------------------------------------------------------------------------
 //  Class:      COooFilterCF
-//  Purpose:    Implements class factory for OpenOffice.org filter
+//  Purpose:    Implements class factory for LibreOffice filter
 //--------------------------------------------------------------------------
 
 class COooFilterCF : public IClassFactory
diff --git a/shell/source/win32/shlxthandler/prophdl/propertyhdl.cxx b/shell/source/win32/shlxthandler/prophdl/propertyhdl.cxx
index 7d21f3a..3d7e60b 100644
--- a/shell/source/win32/shlxthandler/prophdl/propertyhdl.cxx
+++ b/shell/source/win32/shlxthandler/prophdl/propertyhdl.cxx
@@ -63,11 +63,11 @@ struct PROPERTYMAP
 
 PROPERTYMAP g_rgPROPERTYMAP[] =
 {
-    { PKEY_Title,          L"OpenOffice.org",          L"Title" },
-    { PKEY_Author,         L"OpenOffice.org",          L"Author" },
-    { PKEY_Subject,        L"OpenOffice.org",          L"Subject" },
-    { PKEY_Keywords,       L"OpenOffice.org",          L"Keyword" },
-    { PKEY_Comment,        L"OpenOffice.org",          L"Comments" },
+    { PKEY_Title,          L"LibreOffice",          L"Title" },
+    { PKEY_Author,         L"LibreOffice",          L"Author" },
+    { PKEY_Subject,        L"LibreOffice",          L"Subject" },
+    { PKEY_Keywords,       L"LibreOffice",          L"Keyword" },
+    { PKEY_Comment,        L"LibreOffice",          L"Comments" },
 };
 
 size_t gPropertyMapTableSize = SAL_N_ELEMENTS(g_rgPROPERTYMAP);
commit 45295f3cdceb4c289553791071b5d7f4962d2ec4
Author: Andras Timar <atimar at suse.com>
Date:   Tue Mar 27 12:48:53 2012 +0200

    don't install 32-bit shell extensions on 64-bit Windows

diff --git a/scp2/source/winexplorerext/file_winexplorerext.scp b/scp2/source/winexplorerext/file_winexplorerext.scp
index 59a0099..d24a007 100644
--- a/scp2/source/winexplorerext/file_winexplorerext.scp
+++ b/scp2/source/winexplorerext/file_winexplorerext.scp
@@ -37,6 +37,7 @@ File gid_File_Lib_OOoFilt
     Styles = (PACKED);
     Dir = gid_Dir_Shlxthdl;
     Name = "ooofilt.dll";
+    ComponentCondition = "NOT VersionNT64";
 End
 
 #ifdef BUILD_X64
@@ -56,6 +57,7 @@ File gid_File_Lib_Shlxthdl
     Styles = (PACKED);
     Dir = gid_Dir_Shlxthdl;
     Name = "shlxthdl.dll";
+    ComponentCondition = "NOT VersionNT64";
 End
 
 #ifdef BUILD_X64
@@ -74,6 +76,7 @@ File gid_File_Lib_PropertyHdl
     Styles = (PACKED);
     Dir = gid_Dir_Shlxthdl;
     Name = "propertyhdl.dll";
+    ComponentCondition = "NOT VersionNT64";
 End
 
 #ifdef BUILD_X64


More information about the Libreoffice-commits mailing list
diff --git a/shell/source/win32/shlxthandler/ooofilt/ooofilt.cxx b/shell/source/win32/shlxthandler/ooofilt/ooofilt.cxx
index 401ee6f..7d6b15d 100644
--- a/shell/source/win32/shlxthandler/ooofilt/ooofilt.cxx
+++ b/shell/source/win32/shlxthandler/ooofilt/ooofilt.cxx
@@ -31,7 +31,7 @@
 //  File:       ooofilt.cxx
 //  Contents:   Filter Implementation for OpenOffice.Org Document using
 //              Indexing Service
 //  Summary:    The OpenOffice.org filter reads OpenOffice.org files (with the
 //              extension .sxw .sxi, etc) and extract their content, author,
 //              keywords,subject,comments and title to be filtered.
 //  Platform:   Windows 2000, Windows XP
@@ -49,7 +49,7 @@
 //  filterr.h       FACILITY_ITF error definitions for IFilter
 //  ntquery.h       Indexing Service declarations
 //  assert.h        assertion function.
 //  ooofilt.hxx     OpenOffice.org filter declarations
 //  propspec.hxx    PROPSPEC
 //--------------------------------------------------------------------------
 
@@ -78,7 +78,7 @@ using ::std::min;
 
 //C-------------------------------------------------------------------------
 //  Class:      COooFilter
 //  Summary:    Implements OpenOffice.org filter class
 //--------------------------------------------------------------------------
 //M-------------------------------------------------------------------------
 //  Method:     COooFilter::COooFilter
@@ -188,7 +188,7 @@ ULONG STDMETHODCALLTYPE COooFilter::Release()
 }
 //M-------------------------------------------------------------------------
 //  Method:     COooFilter::Init                (IFilter::Init)
 //  Summary:    Initializes OpenOffice.org filter instance
 //  Arguments:  grfFlags
 //                  [in] Flags for filter behavior
 //              cAttributes
@@ -787,7 +787,7 @@ ULONG STDMETHODCALLTYPE COooFilterCF::Release()
 }
 //M-------------------------------------------------------------------------
 //  Method:     COooFilterCF::CreateInstance (IClassFactory::CreateInstance)
 //  Summary:    Creates new OpenOffice.org filter object
 //  Arguments:  pUnkOuter
 //                  [in] Pointer to IUnknown interface of aggregating object
 //              riid
@@ -795,13 +795,13 @@ ULONG STDMETHODCALLTYPE COooFilterCF::Release()
 //              ppvObject
 //                  [out] Address that receives requested interface pointer
 //  Returns:    S_OK
 //                  OpenOffice.org filter object was successfully created
 //              CLASS_E_NOAGGREGATION
 //                  pUnkOuter parameter was non-NULL
 //              E_NOINTERFACE
 //                  (not implemented)
 //              E_OUTOFMEMORY
 //                  OpenOffice.org filter object could not be created
 //                  due to insufficient memory
 //              E_UNEXPECTED
 //                  Unsuccessful due to an unexpected condition
@@ -857,7 +857,7 @@ SCODE STDMETHODCALLTYPE COooFilterCF::LockServer(BOOL fLock)
 }
 //+-------------------------------------------------------------------------
 //  DLL:        ooofilt.dll
 //  Summary:    Implements Dynamic Link Library functions for OpenOffice.org filter
 //--------------------------------------------------------------------------
 //F-------------------------------------------------------------------------
 //  Function:   DllMain
@@ -883,7 +883,7 @@ extern "C" BOOL WINAPI DllMain(
 }
 //F-------------------------------------------------------------------------
 //  Function:   DllGetClassObject
 //  Summary:    Create OpenOffice.org filter class factory object
 //  Arguments:  cid
 //                  [in] Class ID of class that class factory creates
 //              iid
@@ -1017,7 +1017,7 @@ namespace /* private */
 
     //----------------------------------------------
     // Make the registry entry and set Filter Handler
-    // HKCR\CLSID\{7BC0E710-5703-45be-A29D-5D46D8B39262} = OpenOffice.org Filter
+    // HKCR\CLSID\{7BC0E710-5703-45be-A29D-5D46D8B39262} = LibreOffice Filter
     //                   InProcServer32  (Default)       = Path\ooofilt.dll
     //                                   ThreadingModel  = Both
     //----------------------------------------------
@@ -1027,7 +1027,7 @@ namespace /* private */
         std::string ClsidEntry = CLSID_GUID_ENTRY;
         SubstitutePlaceholder(ClsidEntry, GUID_PLACEHOLDER, ClsidToString(FilterGuid));
 
-        if (!SetRegistryKey(HKEY_CLASSES_ROOT, ClsidEntry.c_str(), "", "OpenOffice.org Filter"))
+        if (!SetRegistryKey(HKEY_CLASSES_ROOT, ClsidEntry.c_str(), "", "LibreOffice Filter"))
             return E_FAIL;
 
         ClsidEntry = CLSID_GUID_INPROC_ENTRY;
@@ -1044,7 +1044,7 @@ namespace /* private */
 
     //----------------------------------------------
     // Make the registry entry and set Persistent Handler
     // HKCR\CLSID\{7BC0E713-5703-45be-A29D-5D46D8B39262}  = OpenOffice.org Persistent Handler
     //      PersistentAddinsRegistered
     //          {89BCB740-6119-101A-BCB7-00DD010655AF} = {7BC0E710-5703-45be-A29D-5D46D8B39262}
     //----------------------------------------------
@@ -1055,7 +1055,7 @@ namespace /* private */
         SubstitutePlaceholder(ClsidEntry_Persist, GUID_PLACEHOLDER, ClsidToString(PersistentGuid));
 
 
-        if (!SetRegistryKey(HKEY_CLASSES_ROOT, ClsidEntry_Persist.c_str(), "", "OpenOffice.org Persistent Handler"))
+        if (!SetRegistryKey(HKEY_CLASSES_ROOT, ClsidEntry_Persist.c_str(), "", "LibreOffice Persistent Handler"))
             return E_FAIL;
 
         // Add missing entry
@@ -31,7 +31,7 @@
 //  Contents:   Filter Implementation for OpenOffice.Org Document using
 //              Indexing Service
-//  Summary:    The OpenOffice.org filter reads OpenOffice.org files (with the
+//  Summary:    The LibreOffice filter reads LibreOffice files (with the
 //              extension .sxw .sxi, etc) and extract their content, author,
 //              keywords,subject,comments and title to be filtered.
@@ -49,7 +49,7 @@
 //  ntquery.h       Indexing Service declarations
 //  assert.h        assertion function.
-//  ooofilt.hxx     OpenOffice.org filter declarations
+//  ooofilt.hxx     LibreOffice filter declarations
 //  propspec.hxx    PROPSPEC
 //--------------------------------------------------------------------------
@@ -78,7 +78,7 @@ using ::std::min;
 //C-------------------------------------------------------------------------
 //  Class:      COooFilter
-//  Summary:    Implements OpenOffice.org filter class
+//  Summary:    Implements LibreOffice filter class
 //--------------------------------------------------------------------------
 //M-------------------------------------------------------------------------
@@ -188,7 +188,7 @@ ULONG STDMETHODCALLTYPE COooFilter::Release()
 //M-------------------------------------------------------------------------
 //  Method:     COooFilter::Init                (IFilter::Init)
-//  Summary:    Initializes OpenOffice.org filter instance
+//  Summary:    Initializes LibreOffice filter instance
 //  Arguments:  grfFlags
 //                  [in] Flags for filter behavior
@@ -787,7 +787,7 @@ ULONG STDMETHODCALLTYPE COooFilterCF::Release()
 //M-------------------------------------------------------------------------
 //  Method:     COooFilterCF::CreateInstance (IClassFactory::CreateInstance)
-//  Summary:    Creates new OpenOffice.org filter object
+//  Summary:    Creates new LibreOffice filter object
 //  Arguments:  pUnkOuter
 //                  [in] Pointer to IUnknown interface of aggregating object
@@ -795,13 +795,13 @@ ULONG STDMETHODCALLTYPE COooFilterCF::Release()
 //                  [out] Address that receives requested interface pointer
 //  Returns:    S_OK
-//                  OpenOffice.org filter object was successfully created
+//                  LibreOffice filter object was successfully created
 //              CLASS_E_NOAGGREGATION
 //                  pUnkOuter parameter was non-NULL
@@ -795,13 +795,13 @@ ULONG STDMETHODCALLTYPE COooFilterCF::Release()
 //                  (not implemented)
 //              E_OUTOFMEMORY
-//                  OpenOffice.org filter object could not be created
+//                  LibreOffice filter object could not be created
 //                  due to insufficient memory
 //              E_UNEXPECTED
@@ -857,7 +857,7 @@ SCODE STDMETHODCALLTYPE COooFilterCF::LockServer(BOOL fLock)
 //+-------------------------------------------------------------------------
 //  DLL:        ooofilt.dll
-//  Summary:    Implements Dynamic Link Library functions for OpenOffice.org filter
+//  Summary:    Implements Dynamic Link Library functions for LibreOffice filter
 //--------------------------------------------------------------------------
 //F-------------------------------------------------------------------------
@@ -883,7 +883,7 @@ extern "C" BOOL WINAPI DllMain(
 //F-------------------------------------------------------------------------
 //  Function:   DllGetClassObject
-//  Summary:    Create OpenOffice.org filter class factory object
+//  Summary:    Create LibreOffice filter class factory object
 //  Arguments:  cid
 //                  [in] Class ID of class that class factory creates
@@ -1044,7 +1044,7 @@ namespace /* private */
     //----------------------------------------------
     // Make the registry entry and set Persistent Handler
-    // HKCR\CLSID\{7BC0E713-5703-45be-A29D-5D46D8B39262}  = OpenOffice.org Persistent Handler
+    // HKCR\CLSID\{7BC0E713-5703-45be-A29D-5D46D8B39262}  = LibreOffice Persistent Handler
     //      PersistentAddinsRegistered
     //          {89BCB740-6119-101A-BCB7-00DD010655AF} = {7BC0E710-5703-45be-A29D-5D46D8B39262}